package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.DoumuProductHistory;

/**
 * 痘姆古陶主历史信息Mapper接口
 * 
 * @author boman
 * @date 2024-01-16
 */
public interface DoumuProductHistoryMapper 
{
    /**
     * 查询痘姆古陶主历史信息
     * 
     * @param historyId 痘姆古陶主历史信息主键
     * @return 痘姆古陶主历史信息
     */
    public DoumuProductHistory selectDoumuProductHistoryByHistoryId(Long historyId);

    /**
     * 查询痘姆古陶主历史信息列表
     * 
     * @param doumuProductHistory 痘姆古陶主历史信息
     * @return 痘姆古陶主历史信息集合
     */
    public List<DoumuProductHistory> selectDoumuProductHistoryList(DoumuProductHistory doumuProductHistory);

    /**
     * 新增痘姆古陶主历史信息
     * 
     * @param doumuProductHistory 痘姆古陶主历史信息
     * @return 结果
     */
    public int insertDoumuProductHistory(DoumuProductHistory doumuProductHistory);

    /**
     * 修改痘姆古陶主历史信息
     * 
     * @param doumuProductHistory 痘姆古陶主历史信息
     * @return 结果
     */
    public int updateDoumuProductHistory(DoumuProductHistory doumuProductHistory);

    /**
     * 删除痘姆古陶主历史信息
     * 
     * @param historyId 痘姆古陶主历史信息主键
     * @return 结果
     */
    public int deleteDoumuProductHistoryByHistoryId(Long historyId);

    /**
     * 批量删除痘姆古陶主历史信息
     * 
     * @param historyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDoumuProductHistoryByHistoryIds(Long[] historyIds);
}
